<?php

namespace Drupal\commerce_dibs\PluginForm\OffsiteRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the Off-site Redirect payment gateway form.
 */
class PaymentOffsiteForm extends BasePaymentOffsiteForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    // DIBS is settings the base amount value as cents.
    $amount = $payment->getAmount()->getNumber() * 100;
    $currency_code = $payment->getAmount()->getCurrencyCode();
    $order_id = $payment->getOrderId();

    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    // DIBS only accepts the http post method.
    $redirect_method = 'post';
    $redirect_url = $payment_gateway_plugin->getConfiguration()['redirect_url'];
    $dibs_merchant_id = $payment_gateway_plugin->getConfiguration()['merchant'];
    $language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $pay_type = $payment_gateway_plugin->getConfiguration()['pay_type'];
    $account = $payment_gateway_plugin->getConfiguration()['account'];

    $data = [
      'acceptReturnUrl' => $form['#return_url'],
      'amount' => $amount,
      'currency' => $currency_code,
      'merchant' => $dibs_merchant_id,
      'orderId' => $order_id,
      'cancelReturnUrl' => $form['#cancel_url'],
      'language' => $language,
    ];

    if ($form['#capture']) {
      $data['captureNow'] = 1;
    }

    if (!empty($pay_type)) {
      $data['payType'] = $pay_type;
    }
    if (!empty($account)) {
      $data['account'] = $account;
    }
    if ($payment_gateway_plugin->getConfiguration()['mode'] == 'test') {
      $data['test'] = 1;
    }

    return $this->buildRedirectForm($form, $form_state, $redirect_url, $data, $redirect_method);
  }

}
